@@ -4,12 +4,6 @@ from code_executor_py import VenvExecutor
 from langchain_openai import ChatOpenAI
 
 
-os.environ['OPENAI_API_KEY'] = 'sk-hgJ1UiRTg86R33AFEfscUWidCc2Ex-bqbuYESH2OTlT3BlbkFJXQFJuH9fHt9r3SBR377_BUP7b66CGxoDFRcp-Q43UA'
-
-llm = ChatOpenAI(
-        model="gpt-4o",
-    )
-
 func_code = """
 
 from sklearn.preprocessing import StandardScaler
@@ -27,9 +21,7 @@ def process_data(data_df):
     return pd.DataFrame(scaler.fit_transform(data_df), columns=data_df.columns)
     """
 
-executor = VenvExecutor(
-    # llm=some_llm
-) 
+executor = VenvExecutor() 
 # Create executable function
 process_data = executor.create_executable(func_code)
 
@@ -38,7 +30,7 @@ process_data = executor.create_executable(func_code)
 test_data = pd.DataFrame({'A': [1, 2, 3], 'B': [4, 5, 6]})
 
 # Execute the function and get the result
-result = process_data(data_df =  test_data)
+result = process_data(data_df = test_data)
 
 print(result)
 
